import 'package:flutter/material.dart';

class RecupTextOrButtonFormField extends StatelessWidget {
  final TextEditingController? controller;
  final String? initialValue;
  final String label;
  final Widget? suffixIcon;
  final Widget? prefixIcon;
  final TextAlign textAlign;
  final void Function(String?)? onSaved;
  final void Function()? onTap;
  final TextInputType? keyboardType;
  final bool isButton;
  final bool? isDense;
  const RecupTextOrButtonFormField({
    Key? key,
    this.controller,
    this.initialValue,
    this.label = '',
    this.suffixIcon,
    this.prefixIcon,
    this.textAlign = TextAlign.start,
    this.onSaved,
    this.onTap,
    this.keyboardType,
    this.isButton = false,
    this.isDense,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final isPassWord = keyboardType == TextInputType.visiblePassword;
    final obscure = ValueNotifier(true);

    return AnimatedBuilder(
      animation: obscure,
      builder: (context, child) {
        return TextFormField(
          controller: controller,
          initialValue: initialValue,
          textAlign: textAlign,
          onSaved: onSaved,
          onTap: onTap,
          obscureText: isPassWord ? obscure.value : false,
          keyboardType: isButton ? TextInputType.none : keyboardType,
          decoration: InputDecoration(
            isDense: isDense,
            label: Text(label),
            suffixIcon: isPassWord
                ? GestureDetector(
                    onTap: () {
                      obscure.value = !obscure.value;
                    },
                    child: SizedBox(
                      width: 50,
                      child: Icon(
                        Icons.visibility,
                        color: obscure.value ? Colors.grey : Colors.black,
                      ),
                    ),
                  )
                : suffixIcon,
            prefixIconColor: isButton ? Colors.white : null,
            suffixIconColor: isButton ? Colors.white : null,
            prefixIcon: isPassWord ? null : prefixIcon,
            border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(100),
            ),
            focusedBorder: isButton
                ? OutlineInputBorder(
                    borderRadius: BorderRadius.circular(100),
                    borderSide: const BorderSide(
                      color: Colors.white,
                    ),
                  )
                : null,
          ),
        );
      },
    );
  }
}
